//=============================================================================
// FUNCTION : SELPRINTER()
//  PURPOSE : Selectes destination of Print Request
//   CALLED : _PrintInvo  QuickPrintWo  WorkNew   SaleNew   WorkPkUp
//            ShowUnSold  WorkEdit      SearchFor RptDaily  RptMonth
//            CustPrices  Transact      InvDup    Summary   RptContracts
//            VendYtd     RmaYtd        PoNew     PoRPrnt   ArReport
//            Rma         WoRePrnt
//    CALLS : NIL
//   IMPORT : aApp, cText, nPMode, lNotes, lWoNew, lPg2
//   EXPORT : lOk
//   UPDATE : 27 JUL 2011
//=============================================================================

function SelPrinter(aApp, cText, nPMode, lNotes, lWoNew, lPg2)

  local oMyDlg, getlist := {}, GetOptions, lOk, cNotes := "", oBar
  local lTimeOut, nTimeOut, nMin, nSec, oMin, oSec, oTime, i
  local cFont := "14.Courier New.BOLD"

  store  0  to nMin, nsec
  //
  DC_ValType(@lWoNew,.F., @lPg2,.F., @lNotes,.F., @cText,"", @lTimeOut,.F.)
  //
  if valtype(aVoice) == 'A'
    lpEMail := .F.
  endif
  //
  DC_ClearEvents()
  //-
  //-- Check for printer timeout setting
  //-
  if !empty(@aApp)
    nTimeOut := npPTime
    if nTimeOut > 0
      nMin   := int( nTimeOut / 60 )
      nSec   := nTimeOut % 60
    endif
  else
    nTimeOut := 0
  endif
  //
  nPMode     := 1
  //-
  //-- If Workorder do we want 2nd page
  //-
  if lWoNew .and. valtype(aCfg) = 'A'
    lPg2 := CF_TWOPAGE
  endif
  //
  DCSETPARENT TO oMyDlg
  @01,05 DCSAY "SELECT PRINTER FOR " + alltrim(cText) SIZE 90 FONT cFont
  @03,03 DCRADIO  nPMode  PROMPT "DEFAULT Printer" VALUE 1
  @03,21 DCRADIO  nPMode  PROMPT "Send to Printer" VALUE 2
  @03,36 DCRADIO  nPMode  PROMPT "Send to Screen"  VALUE 3
  //-
  //-- Checkbox for workorder page 2
  //-
  if lWoNew .and. valtype(aCfg) = 'A'
    @05,01 DCCHECKBOX lPg2      PROMPT "Include Page 2"
  endif
  //-
  //-- Auto Cancel Display the time out
  //-
  if nTimeOut # 0
    @07,10 DCSAY "CANCEL in"          SIZE 15 FONT cFont
    @07,25 DCSAY {|| str(nMin,3,0) }  SIZE  5 FONT cFont  SAYOBJECT oMin
    @07,28 DCSAY "min"                SIZE  5 FONT cFont
    @07,35 DCSAY {|| str(nSec,2,0) }  SIZE  5 FONT cFont  SAYOBJECT oSec
    @07,38 DCSAY "sec"                SIZE  5 FONT cFont
  endif
  //-
  //-- Check for EMail
  //-
  if valtype(aVoice) = 'A' .and. !empty(cpEMail)
    @09,10 DCCHECKBOX lpEMail PROMPT "Send Invoice VIA EMail"
  endif
  DCSETPARENT TO
  //
  DC_ClearEvents()
  //
  @13,02 DCTOOLBAR oBar SIZE 18,1.2 BUTTONSIZE 9,1.2
  //
  DCSETPARENT TO oBar
  DCADDBUTTONXP CAPTION "PRINT" COLOR   X_GREEN   X_BORDER                    ;
      ACTION {|| lOk := .T.,  DC_ReadGuiEvent(DCGUI_EXIT_OK,    getlist) }
  DCADDBUTTONXP CAPTION "DONE"  COLOR   X_YELLOW  X_BORDER                    ;
      ACTION {|| lOk := .F.,  DC_ReadGuiEvent(DCGUI_EXIT_ABORT, getlist) }
  DCSETPARENT TO
  //
  DCGETOPTIONS WINDOWHEIGHT 350 WINDOWWIDTH 620 HILITEGETS GRA_CLR_RED        ;
      NOMINBUTTON NOMAXBUTTON NORESIZE EVAL {|o| setappwindow(o) }
  //
  // BUTTONS  OK=1  CANCEL=2  EXIT=4  HELP=8  YES=16  NO=32  CUSTOM=1024
  //
  if nTimeOut # 0
    DCREAD GUI PARENT oMyDlg OPTIONS GetOptions MODAL                         ;
        TIMEOUT { 1, {|| _TimeOut(@nTimeOut,@lTimeOut,@nMin,@nSec,oMin,oSec)}};
        TO lOk
  else
    DCREAD GUI PARENT oMyDlg OPTIONS GetOptions MODAL TO lOk
  endif
  return ( lOk .and. !lTimeOut )


//-----------------------------------------------------------------------------
// FUNCTION : _TIMEOUT()
//  PURPOSE : Cancel time in xMin and xSec
//   CALLED : SelPrinter()
//    CALLS : NONE
//   IMPORT : nTimeOut  - seconds remaining
//            lTimeOut  - reset time if FALSE
//            nMin      - nMin remiaining
//            nSec      - nSec remiaining
//            oMin      - display object for minutes
//            oSec      - display object for seconds
//   EXPORT : FALSE if time still remains else TRUE
//   UPDATE : 15 FEB 09
//-----------------------------------------------------------------------------

static function _TimeOut(nTimeOut, lTimeOut, nMin, nSec, oMin, oSec)

  local i

  nTimeOut--
  i := nTimeOut % 5
  if i = 0
    nTimeOut--
  endif
  if nTimeOut < 10
    tone(440,1)         // 10 Second Warning tones
  endif
  nMin     := int( nTimeOut / 60 )
  nSec     := nTimeout % 60
  lTimeOut := ( nTimeOut < 0 )
  if valtype(oMin) = 'O'
    oMin:setcaption( str(nMin,3,0) )
  endif
  if valtype(oSec) = 'O'
    oSec:setcaption( str(nSec,2,0) )
  endif
  return ( nTimeOut < 0 )


